@@ -1,7 +1,7 @@
 #' Convert to an ioslides Presentation
 #'
 #' Format for converting from R Markdown to an
-#' \href{https://code.google.com/p/io-2012-slides/}{ioslides} presentation.
+#' \href{https://code.google.com/archive/p/io-2012-slides/}{ioslides} presentation.
 #'
 #' @inheritParams html_document
 #' @param logo Path to file that includes a logo for use in the presentation
@@ -19,9 +19,12 @@
 #' @param transition Speed of slide transitions. This can be "default",
 #'   "slower", "faster", or a numeric value with a number of seconds (e.g. 0.5).
 #' @param analytics A Google analytics property ID.
+#'@param smart Produce typographically correct output, converting straight
+#'  quotes to curly quotes, \code{---} to em-dashes, \code{--} to en-dashes, and
+#'  \code{...} to ellipses.
 #' @return R Markdown output format to pass to \code{\link{render}}.
 #' @details
-#'   See the \href{http://rmarkdown.rstudio.com/ioslides_presentation_format.html}{
+#'   See the \href{https://bookdown.org/yihui/rmarkdown/ioslides-presentation.html}{
 #'   online documentation} for additional details on using the
 #'   \code{ioslides_presentation} format.
 #'
@@ -153,7 +156,7 @@
 #'   shouldn't hesitate to add tables for presenting more complex sets of
 #'   information. Pandoc markdown supports several syntaxes for defining
 #'   tables which are described in the
-#'   \href{http://pandoc.org/README.html}{pandoc online documentation}.
+#'   \href{https://pandoc.org/MANUAL.html}{pandoc online documentation}.
 #' @section Advanced Layout:
 #'   You can center content on a slide by adding the \code{.flexbox}
 #'   and \code{.vcenter} attributes to the slide title. For example:
@@ -220,7 +223,8 @@
 #'   To create a PDF version of a presentation you can use Print to PDF
 #'   from Google Chrome.
 #' @export
-ioslides_presentation <- function(logo = NULL,
+ioslides_presentation <- function(number_sections = FALSE,
+                                  logo = NULL,
                                   slide_level = 2,
                                   incremental = FALSE,
                                   fig_width = 7.5,
@@ -275,18 +279,15 @@ ioslides_presentation <- function(logo = NULL,
 
   # additional css
   for (css_file in css)
-    args <- c(args, "--css", pandoc_path_arg(css_file))
+    args <- c(args, "--css", pandoc_path_arg(css_file, backslash = FALSE))
 
   # content includes
   args <- c(args, includes_to_pandoc_args(includes))
 
   # template path and assets
-  if (!is.null(template) && file.exists(template))
-    args <- c(args, "--template", template)
-  else
-    args <- c(args,
-              "--template",
-              pandoc_path_arg(rmarkdown_system_file("rmd/ioslides/default.html")))
+  if (is.null(template) || !file.exists(template))
+    template <- pkg_file("rmd/ioslides/default.html")
+  args <- c(args, "--template", pandoc_path_arg(template))
 
   # html dependency for ioslides
   extra_dependencies <- append(extra_dependencies,
@@ -343,6 +344,10 @@ ioslides_presentation <- function(logo = NULL,
     # add any custom pandoc args
     args <- c(args, pandoc_args)
 
+    # number sections
+    if (number_sections)
+      args <- c(args, pandoc_lua_filter_args(pkg_file_lua("number-sections.lua")))
+
     lua_writer <- file.path(dirname(input_file), "ioslides_presentation.lua")
     # The input directory may not be writable (on e.g. Shiny Server), so write
     # to the output directory in this case. We don't always do this since
@@ -376,7 +381,7 @@ ioslides_presentation <- function(logo = NULL,
 
     # append main body of script
     file.append(lua_writer,
-                rmarkdown_system_file("rmd/ioslides/ioslides_presentation.lua"))
+                pkg_file("rmd/ioslides/ioslides_presentation.lua"))
 
     output_tmpfile <- tempfile("ioslides-output", fileext = ".html")
     on.exit(unlink(output_tmpfile), add = TRUE)
@@ -412,7 +417,7 @@ ioslides_presentation <- function(logo = NULL,
 
     # base64 encode if needed
     if (self_contained) {
-      slides_lines <- base64_image_encode(slides_lines)
+      slides_lines <- base64_encode_images(slides_lines)
     }
 
     # read the output file
@@ -443,7 +448,7 @@ ioslides_presentation <- function(logo = NULL,
     df_print = df_print,
     pre_processor = pre_processor,
     post_processor = post_processor,
-    base_format = html_document_base(smart = smart, lib_dir = lib_dir,
+    base_format = html_document_base(lib_dir = lib_dir,
                                      self_contained = self_contained,
                                      mathjax = mathjax,
                                      pandoc_args = pandoc_args,
@@ -456,7 +461,7 @@ html_dependency_ioslides <- function() {
   htmlDependency(
     name = "ioslides",
     version = "13.5.1",
-    src = rmarkdown_system_file("rmd/ioslides/ioslides-13.5.1"),
+    src = pkg_file("rmd/ioslides/ioslides-13.5.1"),
     script = c(
       "js/modernizr.custom.45394.js",
       "js/prettify/prettify.js",
@@ -472,4 +477,3 @@ html_dependency_ioslides <- function() {
       "theme/css/phone.css")
     )
 }
-
