@@ -1,19 +1,21 @@
 context("resource discovery")
 
 test_that("R Markdown resource discovery finds expected resources", {
-
+  # Test with the current version of the template
+  file.copy(pkg_file("rmd/h/default.html"), 'resources/template.html')
   resources <- find_external_resources("resources/rmarkdown.Rmd")
   expected <- data.frame(
     path = c("empty.md", "empty.png", "empty.tsv", "empty.Rmd", "empty.css",
-             "empty.jpg", "empty.html", "empty.csv"),
-    explicit = c(FALSE, FALSE, TRUE,  FALSE, FALSE, FALSE, FALSE, FALSE),
-    web      = c(FALSE, FALSE, FALSE, FALSE, TRUE,  TRUE,  TRUE,  FALSE),
+             "empty.jpg", "empty.html", "template.html", "empty.csv"),
+    explicit = c(FALSE, FALSE, TRUE,  FALSE, FALSE, FALSE, FALSE, FALSE, FALSE),
+    web      = c(FALSE, FALSE, FALSE, FALSE, TRUE,  TRUE,  TRUE,  FALSE,  FALSE),
     stringsAsFactors = FALSE)
 
-  # sort by filename to avoid errors arising from file ordering -- we don't
-  # really care what order these come back in
+  # sort by filename and remove rownames to avoid errors arising from file ordering
+  # -- we don't really care what order these come back in
   resources <- as.data.frame(resources[order(resources[[1]]), , drop = FALSE])
   expected <- as.data.frame(expected[order(expected[[1]]), , drop = FALSE])
+  rownames(resources) <- rownames(expected) <- NULL
 
   expect_equal(resources, expected)
 })
